/*
Copyright (c) 2007 Austin Wise

Permission is hereby granted, free of charge, to any person
obtaining a copy of this software and associated documentation
files (the "Software"), to deal in the Software without
restriction, including without limitation the rights to use,
copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the
Software is furnished to do so, subject to the following
conditions:

The above copyright notice and this permission notice shall be
included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
OTHER DEALINGS IN THE SOFTWARE.
*/

using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Text;
using System.Management;

namespace Austin.Windows
{
    public class Account
    {
        internal Account(ManagementBaseObject obj)
        {
            _caption = obj.GetPropertyValue("Caption").ToString();
            _description = obj.GetPropertyValue("Description").ToString();
            _domain = obj.GetPropertyValue("Domain").ToString();
            _localAccount = (bool)obj.GetPropertyValue("LocalAccount");
            _name = obj.GetPropertyValue("Name").ToString();
            _sid = obj.GetPropertyValue("SID").ToString();
            _sidType = (SIDType)(byte)obj.GetPropertyValue("SIDType");
            _status = obj.GetPropertyValue("Status").ToString();
        }

        private string _caption;
        public string Caption
        {
            get { return _caption; }
        }

        private string _description;
        public string Description
        {
            get { return _description; }
        }

        private string _domain;
        public string Domain
        {
            get { return _domain; }
        }

        private bool _localAccount;
        public bool LocalAccount
        {
            get { return _localAccount; }
        }

        private string _name;
        public string Name
        {
            get { return _name; }
        }

        private string _sid;
        public string SID
        {
            get { return _sid; }
        }

        private SIDType _sidType;
        public SIDType SIDType
        {
            get { return _sidType; }
        }

        private string _status;
        public string Status
        {
            get { return _status; }
        }

        public static ReadOnlyCollection<Account> GetLocalAccounts()
        {
            ManagementObjectSearcher searcher = new ManagementObjectSearcher("Select * from Win32_Account  Where LocalAccount = True AND SIDType = 1");
            ManagementObjectCollection objects = searcher.Get();
            searcher.Dispose();
            List<Account> accounts = new List<Account>(objects.Count);
            foreach (ManagementBaseObject obj in objects)
            {
                accounts.Add(new Account(obj));
                obj.Dispose();
            }
            searcher.Dispose();
            return new ReadOnlyCollection<Account>(accounts);
        }
    }
}
